local AddonName, AddonTable = ...
local L = AddonTable.Localize
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")

function portalservice_OnLoad()

if EPAConfig == nil then
	EPAConfig = {
		["PortalPrice"] = 'Free',
		["TradeChannel"] = '2',
		["ReadySound"] = 'true',
		["SoundID"] = '1',
		["Advert"] = ''
	}
end

local varload = CreateFrame("Frame")
varload:RegisterEvent("ADDON_LOADED")
varload:SetScript("OnEvent", function(self, event, arg1)
	
	if event == "ADDON_LOADED" and arg1 == "EasyPortalAdvert" then

		local localizedClass, englishClass = UnitClass("player")
		local level = UnitLevel("player")
		local englishFaction, localizedFaction = UnitFactionGroup("player")

		if englishClass ~= "MAGE" then
			message("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r\n\n" .. L["Only Mages can use this addon."])
		else
			DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r v" .. GetAddOnMetadata("EasyPortalAdvert", "Version") .. L[" loaded successfully."])
		end

		plugincheck()
		createadvert()
			
	end

end)

SlashCmdList["ALLPORTS"] = allports
	SLASH_ALLPORTS1 = "/price" -- Changes the price of all portals to the amount specified.

SlashCmdList["LEAVEPARTY"] = leaveparty_command
	SLASH_LEAVEPARTY1 = "/lp" -- Quickly leave a party.

SlashCmdList["SETCDSOUND"] = setcdsound
	SLASH_SETCDSOUND1 = "/cda" -- Set the sound played when a portal ends its cooldown.

SlashCmdList["PREVIEWSOUND"] = previewsound
	SLASH_PREVIEWSOUND1 = "/cdp" -- Preview the sound played when a portal ends its cooldown.

SlashCmdList["PORTALADVERT"] = portaladvert_command
	SLASH_PORTALADVERT1 = "/ad" -- Display the advert

SlashCmdList["TCHAN"] = tradehandler
	SLASH_TCHAN1 = "/tc" -- Set the Trade Channel number.

SlashCmdList["EPAHANDLER"] = epahandler
	SLASH_EPAHANDLER1 = "/epa" -- Handles other EPA related commands.

end

function leaveparty_command()
	LeaveParty()
end

function setcdsound(msg, editbox)

local id = tonumber(msg)

if id < 1 or id > 3 then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r |cFFFF0000[" .. L["Error"] .. "]|r " .. L["Please enter a value between 1 and 3."])
else
	EPAConfig.SoundID = id
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "|r " .. L["Alert sound changed to"] .. " |cFF00FFFFportalready0" .. id .. ".mp3|r.")
end

end

function previewsound(msg, editbox)

local id = tonumber(msg)

if id < 1 or id > 3 then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r |cFFFF0000[" .. L["Error"] .. "]|r " .. L["Please enter a value between 1 and 3."])
else
	PlaySoundFile("Interface\\AddOns\\EasyPortalAdvert\\sound\\portalready0" .. id .. ".mp3")
end

end

function portaladvert_command()

-- This section is the actual advert itself.

local lang = GetDefaultLanguage("player")

if UnitLevel("player") >= 42 then
	SendChatMessage(tostring(EPAConfig.Advert),"CHANNEL",lang,EPAConfig.TradeChannel)
else
	return
end

end

function tradehandler(msg, editbox)

if msg == nil or msg == "" then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r |cFFFF0000[" .. L["Error"] .. "]|r " .. L["Please enter a number."])
else
	local tradechannel = tonumber(msg)
	EPAConfig.TradeChannel = tradechannel
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r " .. L["Trade Channel number changed to"] .. " |cFF00FFFF" .. msg .. "|r.")
end

end

function epahandler(msg)

local localizedClass, englishClass = UnitClass("player")
local englishFaction, localizedFaction = UnitFactionGroup("player")
local level = UnitLevel("player")

if msg == nil or msg == "" then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r |cFFFF0000[" .. L["Error"] .. "]|r " .. L["Please use one of the following arguments:"])
	DEFAULT_CHAT_FRAME:AddMessage(L["info"] .. "," .. L["help"] .. "," .. L["sound"] .. "," .. L["create"])
elseif msg == L["sound"] then
	if EPAConfig.ReadySound == "true" then
		EPAConfig.ReadySound = 'false'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["The cooldown alert sound has been disabled."])
	elseif EPAConfig.ReadySound == "false" then
		EPAConfig.ReadySound = 'true'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["The cooldown alert sound has been enabled."])
	end
elseif msg == L["info"] then

local GUI = LibStub("AceGUI-3.0") 
local frame = GUI:Create("Frame") 

frame:SetTitle("Settings") 
frame:SetStatusText("Version " ..GetAddOnMetadata("EasyPortalAdvert", "Version")) 
local txt,sf 
local example_txt = (L["Easy Portal Advert"] .. L[" is currently using the following settings"] .. ":\n\n|cFF00FF00" .. L["Cost of all portals"] .. ":|r " .. EPAConfig.PortalPrice .. ".\n\n|cFF00FF00" .. L["Trade Channel"] .. ":|r " .. EPAConfig.TradeChannel .. "\n\n" .. L["Your alert sound is"] .. ": |cFF00FFFFInterface\47AddOns\47EasyPortalAdvert\47sound\47portalready0" .. EPAConfig.SoundID .. ".mp3|r.\n\n" .. L["Your advert"] .. ": |cFF00FFFF" .. tostring(EPAConfig.Advert) .. "|r\n\n"):rep(1) 
	 
frame:SetLayout("Fill") 
	 
txt = GUI:Create("Label") 
txt:SetFullWidth(true) 
txt:SetText(example_txt) 

sf = GUI:Create("ScrollFrame") 
sf:SetLayout("Flow") 
sf:AddChild(txt) 

frame:AddChild(sf)

elseif msg == L["help"] then

local GUI = LibStub("AceGUI-3.0") 
local frame = GUI:Create("Frame") 

frame:SetTitle("EPA Help") 
frame:SetStatusText("Version " ..GetAddOnMetadata("EasyPortalAdvert", "Version")) 
local txt,sf 
local example_txt = ("|cFFFFFF00" .. L["Easy Portal Advert"] .. " - " .. L["Command List"] .. "|r\n\n|cFF00FF00/epa " .. L["info"] .. "|r - " .. L["Displays the current settings being used by the addon"] .. ".\n|cFF00FF00/epa " .. L["sound"] .. "|r - " .. L["Toggles the cooldown alert sound on or off"] .. ".\n|cFF00FF00/epa " .. L["create"] .. "|r - " .. L["Forces the addon to recreate your advert"] .. ".\n\n|cFFFFFF00" .. L["PRICE SETTINGS"] .. "|r\n\n|cFF00FF00/" .. L["price"] .. " <X>|r - " .. L["Set the price for all of your portals"] .. ".\n\n|cFFFFFF00" .. L["CHANNEL SETTINGS"] .. "|r\n\n|cFF00FF00/tc <X>|r - " .. L["Tells the addon what channel number to use for Trade chat (usually 2)"] .. ".\n\n|cFFFFFF00" .. L["DISPLAYING ADVERTS"] .. "|r\n\n|cFF00FF00/ad|r - " .. L["Displays your advert in Trade chat"] .. ".\n\n|cFFFFFF00" .. L["ALERT SOUND SETTINGS"] .. "|r\n\n|cFF00FF00/cda <1-3>|r - " .. L["Tells the addon which sound to play when a portal finishes its cooldown (unless this feature is disabled)"] .. ".\n|cFF00FF00/cdp <1-3>|r - " .. L["Preview one of the 3 alert sounds"] .. ".\n\n|cFFFFFF00" .. L["OTHER COMMANDS"] .. "|r\n\n|cFF00FF00/lp|r - " .. L["Quickly leave your current party"] .. "."):rep(1) 	 
frame:SetLayout("Fill") 
	 
txt = GUI:Create("Label") 
txt:SetFullWidth(true) 
txt:SetText(example_txt) 

sf = GUI:Create("ScrollFrame") 
sf:SetLayout("Flow") 
sf:AddChild(txt) 

frame:AddChild(sf)

elseif msg == L["create"] then
	createadvert()
end
end

function plugincheck()

	cdm = IsAddOnLoaded("EPA-CooldownMonitor")

		if cdm == true then
			DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["Cooldown Monitor is enabled"] .. ".")
		else
			DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["Cooldown Monitor is disabled"] .. ".")
		end

end

function allports(msg, editbox)

if msg == nil or msg == "" then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .. "]|r |cFFFF0000[" .. L["Error"] .. "]|r " .. L["Please enter a price"] .. ".")
elseif msg == "free" or msg == "Free" or msg == "0" then
	EPAConfig.PortalPrice = 'Free'
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["All of your portals are now free"] .. ".")
	createadvert()
elseif msg == "pwyw" or msg == "PWYW" then
	EPAConfig.PortalPrice = 'PWYW'
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["All of your portals are now set to Pay What You Want"] .. ".")
	createadvert()
else
	local priceall = msg
	EPAConfig.PortalPrice = priceall
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["Easy Portal Advert"] .."]|r " .. L["All of your portals are now"] .. " " .. priceall .. ".")
	createadvert()
end

end

function createadvert()

-- I am currently unsure how to localise the advert, as trying to do so results in errors.

local level = UnitLevel("player")
local englishFaction, localizedFaction = UnitFactionGroup("player")
local lang = GetDefaultLanguage("player")
local locale = GetLocale()

if EPAConfig.PortalPrice == "Free" then
	if locale == "enUS" or locale == "enGB" then
		EPAConfig.Advert = 'Free portals!'
	elseif locale == "frFR" then
		EPAConfig.Advert = 'Portails gratuits!'
	elseif locale == "deDE" then
		EPAConfig.Advert = 'Gratis-Portale!'
	end
elseif EPAConfig.PortalPrice == "PWYW" then
	if locale == "enUS" or locale == "enGB" then
		EPAConfig.Advert = 'Pay What You Want portal service available!'
	elseif locale == "frFR" then
		EPAConfig.Advert = 'Payez ce que vous voulez service de portail disponible!'
	elseif locale == "deDE" then
		EPAConfig.Advert = 'Bezahlen was Sie Portal-Service zur Verfügung wünschen!'
	end
elseif EPAConfig.PortalPrice ~= "Free" and EPAConfig.PortalPrice ~= "PWYW" then
	if locale == "enUS" or locale == "enGB" then
		EPAConfig.Advert = 'Portals available for ' .. EPAConfig.PortalPrice
	elseif locale == "frFR" then
		EPAConfig.Advert = 'Portails disponibles pour ' .. EPAConfig.PortalPrice
	elseif locale == "deDE" then
		EPAConfig.Advert = 'Portale zur Verfügung: ' .. EPAConfig.PortalPrice
	end
end

end